Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6062)

Unified Diff: chrome/browser/extensions/activity_log.h

Issue 13726026: Added ActivityLog tests and associated bugfixes/extra logging. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Wrapped line Created 7 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/activity_log.h
diff --git a/chrome/browser/extensions/activity_log.h b/chrome/browser/extensions/activity_log.h
index 4c2379c199c7cc067dfeb5cc2885dc11204020db..eb4f0e5dc1dbb9fcc53bd310ca5b5919251ca92b 100644
--- a/chrome/browser/extensions/activity_log.h
+++ b/chrome/browser/extensions/activity_log.h
@@ -200,11 +200,11 @@ class ActivityLog : public ProfileKeyedService,
bool log_activity_to_stdout_;
bool log_activity_to_ui_;
// log_arguments controls whether to log API call arguments. By default, we
// don't log most arguments to avoid saving too much data. In testing mode,
// argument collection is enabled. We also whitelist some arguments for
// collection regardless of whether this bool is true.
- bool log_arguments_;
+ bool testing_mode_;
base::hash_set<std::string> arg_whitelist_api_;
DISALLOW_COPY_AND_ASSIGN(ActivityLog);
« no previous file with comments | « no previous file | chrome/browser/extensions/activity_log.cc » ('j') | chrome/renderer/extensions/api_activity_logger.h » ('J')
@@ -200,11 +200,11 @@ class ActivityLog : public ProfileKeyedService,
bool log_activity_to_stdout_;
bool log_activity_to_ui_;
- // log_arguments controls whether to log API call arguments. By default, we
+ // testing_mode_ controls whether to log API call arguments. By default, we
// don't log most arguments to avoid saving too much data. In testing mode,
// argument collection is enabled. We also whitelist some arguments for

Powered by Google App Engine
This is Rietveld 408576698